package Locale::CLDR::Is::Any;

# This file auto generated
#	on Tue 10 Jun  9:24:06 pm GMT

use version;

our $VERSION = version->declare('v0.25.3');

use v5.10;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

extends('Locale::CLDR::Is');

no Moose;
__PACKAGE__->meta->make_immutable;
